@@ -22,7 +22,7 @@ class applyDiscount : public XDialog, public Ui::applyDiscount
     Q_OBJECT
 
 public:
-    applyDiscount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    applyDiscount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~applyDiscount();
 
 public slots:
