@@ -10,6 +10,7 @@
 
 #include "createLotSerial.h"
 
+#include <QDebug>
 #include <QMessageBox>
 #include <QSqlError>
 #include <QValidator>
@@ -101,7 +102,9 @@ enum SetResponse createLotSerial::set(const ParameterList &pParams)
                         "FROM lsdetail JOIN ls ON (ls_id=lsdetail_ls_id) "
                         "WHERE ( (lsdetail_source_number=:docnumber) "
                         "AND (lsdetail_source_type=:transtype) "
-                        "AND (lsdetail_itemsite_id=:itemsite) "
+                        "AND (lsdetail_itemsite_id IN (SELECT itemsite_id FROM itemsite "
+                        "                              WHERE itemsite_item_id = (SELECT itemsite_item_id "
+                        "                               FROM itemsite WHERE itemsite_id = :itemsite))) "
                         "AND (lsdetail_qtytoassign > 0) ) "
                         "GROUP BY 2,3");
       preassign.bindValue(":transtype", createet.value("invhist_transtype").toString());
@@ -214,8 +217,7 @@ void createLotSerial::sHandleCharacteristics()
         {
             qDebug() << __FUNCTION__ << __LINE__ << charQuery.lastError().text();
         }
-        int i=0;
-        while(charQuery.next())
+        for (int i = 0; charQuery.next() && i < _charWidgets.length(); i++)
         {
             QString charass_value = charQuery.value("charass_value").toString();
             int char_type = charQuery.value("char_type").toInt();
@@ -228,11 +230,12 @@ void createLotSerial::sHandleCharacteristics()
             else if (char_type == 1)
             {
                 XComboBox *x = qobject_cast<XComboBox *>(_charWidgets.at(i));
-                int index = x->findText(charass_value);
-                if (index > -1) {
+                if (x) {
+                  int index = x->findText(charass_value);
+                  if (index > -1) {
                     x->setCurrentIndex(index);
+                  }
                 }
-
             }
             else
             {
@@ -240,7 +243,6 @@ void createLotSerial::sHandleCharacteristics()
                 if (l)
                     l->setText(charass_value);
             }
-            i++;
         }
     }
     else
@@ -261,17 +263,20 @@ void createLotSerial::clearCharacteristics()
       if (char_types.at(i) == 2)
       {
           DLineEdit *l = qobject_cast<DLineEdit *>(_charWidgets.at(i));
-          l->clear();
+          if (l)
+            l->clear();
       }
       else if (char_types.at(i) == 1)
       {
           XComboBox *x = qobject_cast<XComboBox *>(_charWidgets.at(i));
-          x->setCurrentIndex(0);
+          if (x)
+            x->setCurrentIndex(0);
       }
       else
       {
           QLineEdit *l = qobject_cast<QLineEdit *>(_charWidgets.at(i));
-          l->clear();
+          if (l)
+            l->clear();
       }
    }
 }
