@@ -24,7 +24,7 @@ class currenciesDialog : public QDialog
   Q_OBJECT
 
   public:
-    currenciesDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    currenciesDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~currenciesDialog();
   
   protected:
