@@ -20,7 +20,7 @@ class dspPoReturnsByVendor : public display, public Ui::dspPoReturnsByVendor
     Q_OBJECT
 
 public:
-    dspPoReturnsByVendor(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspPoReturnsByVendor(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
