@@ -20,7 +20,7 @@ class dspValidLocationsByItem : public display, public Ui::dspValidLocationsByIt
     Q_OBJECT
 
 public:
-    dspValidLocationsByItem(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspValidLocationsByItem(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
