@@ -22,7 +22,7 @@ class externalCCTransaction : public XDialog, public Ui::externalCCTransaction
     Q_OBJECT
 
 public:
-    externalCCTransaction(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    externalCCTransaction(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~externalCCTransaction();
 
 public slots:
