@@ -21,7 +21,7 @@ class financialLayouts : public XWidget, public Ui::financialLayouts
     Q_OBJECT
 
 public:
-    financialLayouts(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    financialLayouts(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~financialLayouts();
 
 public slots:
