@@ -28,7 +28,7 @@ class helpDownload : public XWidget, public Ui::helpDownload
       Busy
     };
 public:
-    helpDownload(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    helpDownload(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~helpDownload();
 
 public slots:
