@@ -19,7 +19,7 @@ class postCashReceipts : public XDialog, public Ui::postCashReceipts
     Q_OBJECT
 
 public:
-    postCashReceipts(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    postCashReceipts(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~postCashReceipts();
 
 protected slots:
