@@ -41,6 +41,16 @@ project::project(QWidget* parent, const char* name, bool modal, Qt::WindowFlags
 {
   setupUi(this);
 
+  XSqlQuery projectType;
+  projectType.prepare("SELECT prjtype_id, prjtype_descr FROM prjtype WHERE prjtype_active;");
+  projectType.exec();
+  _projectType->populate(projectType);
+  if (projectType.lastError().type() != QSqlError::NoError)
+  {
+    systemError(this, projectType.lastError().databaseText(), __FILE__, __LINE__);
+    return;
+  }
+
   if(!_privileges->check("EditOwner")) _owner->setEnabled(false);
 
   connect(_buttonBox,     SIGNAL(rejected()),        this, SLOT(sClose()));
@@ -411,21 +421,25 @@ void project::populate()
     _recurring->setParent(projectpopulate.value("prj_recurring_prj_id").isNull() ?
                             _prjid : projectpopulate.value("prj_recurring_prj_id").toInt(),
                           "J");
-  }
 
-  XSqlQuery projectType;
-  projectType.prepare( "SELECT prjtype_id, prjtype_descr FROM prjtype WHERE prjtype_active "
-                       "UNION "
-                       "SELECT prjtype_id, prjtype_descr FROM prjtype "
-                       "JOIN prj ON (prj_prjtype_id=prjtype_id) "
-                       "WHERE (prj_id=:prj_id);" );
-  projectType.bindValue(":prj_id", _prjid);
-  projectType.exec();
-  _projectType->populate(projectType);
-  if (projectType.lastError().type() != QSqlError::NoError)
-  {
-    systemError(this, projectType.lastError().databaseText(), __FILE__, __LINE__);
-    return;
+    if (_projectType->id() < 0)
+    {
+      XSqlQuery projectType;
+      projectType.prepare( "SELECT prjtype_id, prjtype_descr FROM prjtype WHERE prjtype_active "
+                           "UNION "
+                           "SELECT prjtype_id, prjtype_descr FROM prjtype "
+                           "JOIN prj ON (prj_prjtype_id=prjtype_id) "
+                           "WHERE (prj_id=:prj_id);" );
+      projectType.bindValue(":prj_id", _prjid);
+      projectType.exec();
+      _projectType->populate(projectType);
+      if (projectType.lastError().type() != QSqlError::NoError)
+      {
+        systemError(this, projectType.lastError().databaseText(), __FILE__, __LINE__);
+        return;
+      }
+      _projectType->setId(projectpopulate.value("prj_prjtype_id").toInt());
+    }
   }
 
   sFillTaskList();
