@@ -238,10 +238,10 @@ void reserveSalesOrderItem::populate()
                 "       coitem_qtyord AS ordered,"
                 "       (coitem_qtyshipped - coitem_qtyreturned) AS shipped,"
                 "       qtyAtShipping(coitem_id) AS atShipping,"
-                "       coitem_qtyreserved AS reserved,"
+                "       (coitem_qtyreserved / coitem_qty_invuomratio) AS reserved,"
                 "       noNeg(coitem_qtyord - coitem_qtyshipped +"
                 "             coitem_qtyreturned - qtyAtShipping(coitem_id) -"
-                "             coitem_qtyreserved) AS balance "
+                "             (coitem_qtyreserved / coitem_qty_invuomratio)) AS balance "
                 "FROM coitem JOIN cohead ON (cohead_id=coitem_cohead_id)"
                 "            JOIN itemsite ON (itemsite_id=coitem_itemsite_id)"
                 "            JOIN item ON (item_id=itemsite_item_id)"
