@@ -21,7 +21,7 @@ class taxZone : public XDialog, public Ui::taxZone
     Q_OBJECT
 
 public:
-    taxZone(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    taxZone(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~taxZone();
 
 public slots:
